%global srcname pycryptodomex
%global common_description %{expand:
PyCryptodome is a self-contained Python package of low-level cryptographic primitives. It's a fork
of PyCrypto. It brings several enhancements with respect to the last official version of PyCrypto
(2.6.1), for instance:

  * Authenticated encryption modes (GCM, CCM, EAX, SIV, OCB)
  * Accelerated AES on Intel platforms via AES-NI
  * Elliptic curves cryptography (NIST P-256 curve only)
  * Better and more compact API (nonce and iv attributes for ciphers, automatic
    generation of random nonces and IVs, simplified CTR cipher mode, and more)
  * SHA-3 (including SHAKE XOFs) and BLAKE2 hash algorithms
  * Salsa20 and ChaCha20 stream ciphers
  * scrypt and HKDF
  * Deterministic (EC)DSA
  * Password-protected PKCS#8 key containers
  * Shamir's Secret Sharing scheme
  * Random numbers get sourced directly from the OS (and not from a CSPRNG in userspace)
  * Cleaner RSA and DSA key generation (largely based on FIPS 186-4)
  * Major clean ups and simplification of the code base

PyCryptodome is not a wrapper to a separate C library like OpenSSL. To the largest possible extent,
algorithms are implemented in pure Python. Only the pieces that are extremely critical to
performance (e.g. block ciphers) are implemented as C extensions.

Note: all modules are installed under the Cryptodome package to avoid conflicts with the PyCrypto
library.}

Summary:        A self-contained cryptographic library for Python
Name:           python-%{srcname}
Version:        3.20.0
Release:        3%{?dist}
License:        BSD and Public Domain
URL:            http://www.pycryptodome.org/
Source0:        https://github.com/Legrandin/pycryptodome/archive/v%{version}/%{srcname}-%{version}.tar.gz

Patch3000:      %{name}-3.19.0-use_external_libtomcrypt.patch

BuildRequires:  gcc libtomcrypt-devel make python3-devel
BuildRequires:  %{py3_dist sphinx}

%description
%{common_description}

%package -n python3-%{srcname}
Summary:        A self-contained cryptographic library for Python
Requires:       gmp

%description -n python3-%{srcname}
%{common_description}

%package -n python3-%{srcname}-selftest
Summary:        PyCryptodome test suite module
Requires:       python3-%{srcname}

%description -n python3-%{srcname}-selftest
%{common_description}

This package provides the PyCryptodome test suite module (Cryptodome.SelfTest).

%prep
%autosetup -n pycryptodome-%{version} -p0

rm -r src/libtom/
sed  -i '1{\@^#! /usr/bin/env python@d}' lib/Crypto/SelfTest/__main__.py

%generate_buildrequires
export PYCRYPTODOME_DEBUG=1
%pyproject_buildrequires -r

%build
touch .separate_namespace
%pyproject_wheel

%make_build -C Doc/ man SPHINXBUILD=sphinx-build

%install
%pyproject_install
%pyproject_save_files Cryptodome

install -Dpm 0644 Doc/_build/man/pycryptodome.1 %{buildroot}%{_mandir}/man1/pycryptodome.1


%check
PYTHONPATH=%{buildroot}%{python3_sitearch}/ %{__python3} setup.py test

%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE.rst
%doc AUTHORS.rst Changelog.rst README.rst
%exclude %{python3_sitearch}/Cryptodome/SelfTest/
%{_mandir}/man1/pycryptodome.1.*

%files -n python3-%{srcname}-selftest
%{python3_sitearch}/Cryptodome/SelfTest/

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.20.0-3
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.20.0-2
- Rebuilt for loongarch release

* Wed Feb 07 2024 Upgrade Robot <upbot@opencloudos.org> - 3.20.0-1
- Upgrade to version 3.20.0
- fix CVE-2023-52323.

* Mon Sep 25 2023 Miaojun Dong <zoedong@tencent.com> - 3.19.0-1
- Bump version to 3.19.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.14.1-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.14.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.14.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.14.1-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 9 2023 Shuo Wang <abushwang@tencent.com> - 3.14.1-1
- initial build
